SystemOrganization addCategory: #ConfigurationOfDevFlow!

Object subclass: #ConfigurationOfDevFlow
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfDevFlow'!

!ConfigurationOfDevFlow commentStamp: '<historical>' prior: 0!
A ConfigurationOfDevFlow is a specification which loads all my packages as well as all the dependencies.

Thanks to Max Leske & Doru for the help ;)!

!ConfigurationOfDevFlow class methodsFor: 'development support' stamp: 'RobertoMinelli 3/30/2013 12:23'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfDevFlow class methodsFor: 'private' stamp: 'RobertoMinelli 3/30/2013 12:23'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfDevFlow class methodsFor: 'private' stamp: 'RobertoMinelli 3/30/2013 12:23'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfDevFlow class methodsFor: 'private' stamp: 'RobertoMinelli 3/30/2013 12:23'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfDevFlow class methodsFor: 'metacello tool support' stamp: 'RobertoMinelli 3/30/2013 12:23'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfDevFlow class methodsFor: 'loading' stamp: 'RobertoMinelli 3/30/2013 12:23'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfDevFlow class methodsFor: 'loading' stamp: 'RobertoMinelli 2/5/2015 09:44'!
loadAsDev

	<apiDocumentation>

	^(self project version: #bleedingEdge) load: #('Dev').! !

!ConfigurationOfDevFlow class methodsFor: 'loading' stamp: 'RobertoMinelli 2/5/2015 09:47'!
loadAsUser

	<apiDocumentation>

	^(self project version: #bleedingEdge) load: #('User').! !

!ConfigurationOfDevFlow class methodsFor: 'loading' stamp: 'RobertoMinelli 3/30/2013 12:23'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfDevFlow class methodsFor: 'loading' stamp: 'RobertoMinelli 3/30/2013 12:23'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfDevFlow class methodsFor: 'loading' stamp: 'RobertoMinelli 2/5/2015 09:47'!
loadServer

	<apiDocumentation>

	^(self project version: #bleedingEdge) load: #('Server').! !

!ConfigurationOfDevFlow class methodsFor: 'accessing' stamp: 'RobertoMinelli 3/30/2013 12:23'!
project

	^self new project! !

!ConfigurationOfDevFlow class methodsFor: 'development support' stamp: 'RobertoMinelli 3/30/2013 12:23'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfDevFlow methodsFor: 'pre-post-load-do-its' stamp: 'RobertoMinelli 11/8/2013 11:06'!
askToUpdateSessions

	| sessionsManager |
	
	sessionsManager := Smalltalk at: #DFSessionsManager ifAbsent: [ nil ].
	sessionsManager isNil ifTrue: [ ^self ].
	sessionsManager perform: #askToUpdateSessions.! !

!ConfigurationOfDevFlow methodsFor: 'baselines' stamp: 'RobertoMinelli 2/9/2015 17:45'!
baseline100: spec
	<version: '1.0.0-baseline'>
	spec
		for: #common
		do: [ 
			
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/RobertoMinelli/DevFlow/main'.
			
			spec
				package: 'DevFlow-Meta';
				package: 'DevFlow-Core' with: [ spec requires: #('DevFlow-Meta') ];
				package: 'DevFlow-Uploader' with: [ spec requires: #('DevFlow-Core')];
				package: 'DevFlow-Server' with: [ spec requires: #('DevFlow-Core' 'Scheduler')];
				package: 'DevFlow-Utils' with: [ spec requires: #('DevFlow-Core' 'NeoJSON' 'Fuel' 'Scheduler') ];
				package: 'DevFlow-Profilers' with: [ spec requires: #('DevFlow-Core' 'Spy') ];
				package: 'DevFlow-Announcement' with: [ spec requires: #('DevFlow-Utils') ];
				package: 'DevFlow-UI' with: [ spec requires: #('DevFlow-Utils') ];
				package: 'DevFlow-View' with: [ spec requires: #('Roassal') ].
				
			self registerSpyWith: spec.
			self registerNeoJSONWith: spec.
			self registerFuelWith: spec.
			self registerRoassalWith: spec.
			self registerSchedulerWith: spec.
			
			spec group: 'User' with: #(
				'DevFlow-Meta' 
				'DevFlow-Core'
				'DevFlow-Uploader' 
				'DevFlow-Utils' 
				'DevFlow-Profilers' 
				'DevFlow-UI' 
				'DevFlow-Announcement'
				'DevFlow-Extensions').
		
			spec group: 'default' with: #(
				'User').
		
			spec group: 'Dev' with: #(
				'User').
				
			spec group: 'Server' with: #(
				'Dev'
				'DevFlow-Server'
			).
		
			spec postLoadDoIt: #postLoadActionsFor:spec:.
		].
	
		self installForPharo20On: spec.
		self installForPharo30On: spec.
		self installForPharo40On: spec.
	! !

!ConfigurationOfDevFlow methodsFor: 'accessing' stamp: 'RobertoMinelli 3/30/2013 12:23'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfDevFlow methodsFor: 'tags' stamp: 'RobertoMinelli 2/9/2015 17:16'!
development: spec
	<symbolicVersion: #development >
	
	spec for: #'common' version: '1.0.0-baseline'.! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 6/26/2014 14:44'!
installForPharo20On: spec

	spec for: #'pharo2.x'
		do: [ 

			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/RobertoMinelli/DevFlow/main'.
			
			self registerCollectionExtensionsWith: spec.
			
			spec package: 'DevFlow-UI4Pharo20'.
			spec package: 'DevFlow-Extensions' with: 'DevFlow-Extensions30'.
	].! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 6/26/2014 14:44'!
installForPharo30On: spec

	spec for: #'pharo3.x'
		do: [ 

			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/RobertoMinelli/DevFlow/main'.
			
			spec package: 'DevFlow-Extensions' with: 'DevFlow-Extensions30'.
	].! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 6/26/2014 14:44'!
installForPharo40On: spec

	spec for: #'pharo4.x'
		do: [ 

			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/RobertoMinelli/DevFlow/main'.
			
			spec package: 'DevFlow-Extensions' with: 'DevFlow-Extensions40'
	].! !

!ConfigurationOfDevFlow methodsFor: 'pre-post-load-do-its' stamp: 'RobertoMinelli 5/22/2013 08:41'!
openManagerWindow
	| aDFPharoMenu |
	
	aDFPharoMenu := Smalltalk at: #DFPharoMenu ifAbsent: [ nil ].
	aDFPharoMenu isNil ifTrue: [ ^self ].
	aDFPharoMenu perform: #openMiniManagerWindow.! !

!ConfigurationOfDevFlow methodsFor: 'pre-post-load-do-its' stamp: 'RobertoMinelli 2/9/2015 17:42'!
postLoadActionsFor: loader spec: spec

	self askToUpdateSessions .	
	self resetProfilers .
	self startAutoRecording.! !

!ConfigurationOfDevFlow methodsFor: 'accessing' stamp: 'RobertoMinelli 3/30/2013 12:23'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 11/7/2013 11:34'!
registerCollectionExtensionsWith: spec
	spec
		package: 'CollectionExtensions' with: [
			spec
				file: 'CollectionExtensions-TudorGirba.34';
				repository: 'http://www.smalltalkhub.com/mc/Moose/CollectionExtensions/main' ]! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 10/29/2013 11:12'!
registerFuelWith: spec
	spec
		project: 'Fuel' with: [
		spec
			className: 'ConfigurationOfFuel';
			versionString: #stable;
			file: 'ConfigurationOfFuel';
			repository: 'http://smalltalkhub.com/mc/Pharo/Fuel/main' ]! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 5/22/2013 09:08'!
registerMooseWith: spec
	spec 
		project: 'Moose' with: [
		spec
			className: 'ConfigurationOfMoose';
			file: 'ConfigurationOfMoose';
			version: #development;
			loads: #('Core' );
			repository: 'http://www.smalltalkhub.com/mc/Moose/Moose/main' ].! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'MaxLeske 5/21/2013 19:14'!
registerNeoJSONWith: spec
	spec
		project: 'NeoJSON'
		with: [ 
			spec
				className: 'ConfigurationOfNeoJSON';
				versionString: #stable;
				repository: 'http://www.squeaksource.com/MetacelloRepository' ]! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 3/8/2014 15:04'!
registerOldFuelWith: spec
	spec
		project: 'Fuel' with: [
		spec
			className: 'ConfigurationOfFuel';
			version: '1.9.1';
			file: 'ConfigurationOfFuel';
			repository: 'http://smalltalkhub.com/mc/Pharo/Fuel/main' ]! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 10/14/2013 08:37'!
registerRoassalWith: spec
	spec
		project: 'Roassal' with: [
		spec
			className: 'ConfigurationOfRoassal';
			versionString: #development;
			file: 'ConfigurationOfRoassal';
			repository: 'http://www.smalltalkhub.com/mc/ObjectProfile/Roassal/main' ]! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'RobertoMinelli 2/5/2015 09:51'!
registerSchedulerWith: spec
	spec
		project: 'Scheduler' with: [
		spec
			className: 'ConfigurationOfScheduler';
			versionString: #stable;
			file: 'ConfigurationOfScheduler';
			repository: 'http://smalltalkhub.com/mc/TorstenBergmann/Scheduler/main' ]! !

!ConfigurationOfDevFlow methodsFor: 'load-dependencies' stamp: 'MaxLeske 5/21/2013 20:13'!
registerSpyWith: spec
	spec
		project: 'Spy' with: [
		spec
			className: 'ConfigurationOfSpy';
			version: '2.1-baseline';
			loads: #('Core');
			file: 'ConfigurationOfSpy';
			repository: 'http://smalltalkhub.com/mc/ObjectProfile/Spy/main' ]! !

!ConfigurationOfDevFlow methodsFor: 'pre-post-load-do-its' stamp: 'RobertoMinelli 12/18/2013 10:32'!
resetProfilers

	|profSuite|
	
	profSuite := Smalltalk at: #DFProfilersSuite ifAbsent: nil.
	profSuite ifNotNil: [ profSuite reset ].! !

!ConfigurationOfDevFlow methodsFor: 'tags' stamp: 'RobertoMinelli 2/9/2015 17:16'!
stable: spec
	<symbolicVersion: #stable >
	
	spec for: #'common' version: '1.0.0-baseline'.! !

!ConfigurationOfDevFlow methodsFor: 'pre-post-load-do-its' stamp: 'RobertoMinelli 2/5/2015 11:20'!
startAutoRecording

	"Adding the DFAutomator to the startup/shutdown lists and enable"
	DFAutomator registerAndEnable.! !
